#!/bin/sh

# Copyright (C) 2023  Braiins Systems s.r.o.
#
# This file is part of Braiins Open-Source Initiative (BOSI).
#
# BOSI is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# Please, keep in mind that we may also license BOSI or any part thereof
# under a proprietary license. For more information on the terms and conditions
# of such proprietary license or if you have any other questions, please
# contact us at opensource@braiins.com.

set -ex

# Create temporary directory for mounting rootfs so
# if it is run in parallel it does not interfere with each other
MOUNT_PATH="$(mktemp -d)"
TMP_BOS_DIR="/tmp/bos"

# Check if the script is running as root, if not run it self with root privileges
if [ "$(id -u)" -ne 0 ]; then
    /nvdata/bos/rootshell -c $0
    exit 0
fi

# mount rootfs for copy files
mount -o loop /nvdata/bos/rootfs.img "$MOUNT_PATH"

rm -rf "$TMP_BOS_DIR"
mkdir -p "$TMP_BOS_DIR"
# copy essential tools from rootfs (for simple update)
cp \
    "$MOUNT_PATH/usr/bin/bos-tools" \
    "$MOUNT_PATH/sbin/bos-runner.sh" \
    "$MOUNT_PATH/usr/bin/unshare" \
    "$MOUNT_PATH/lib/functions/common.sh" \
    "$TMP_BOS_DIR"

# unmount no longer needed mount of
umount "$MOUNT_PATH"
rm -rf "$MOUNT_PATH"

# Load common constants
. "$TMP_BOS_DIR/common.sh"

# Make action file pipe
rm -f "${ACTION_FILE_PATH}"
mkfifo "${ACTION_FILE_PATH}"

# Create factory configuration and store it to /tmp where bos-defaults.sh can read it
$TMP_BOS_DIR/$BOS_TOOLS_NAME create-factory-conf -o "/tmp/bos_factory.json"

$TMP_BOS_DIR/$BOS_TOOLS_NAME daemonize /bin/sh -- -c "$TMP_BOS_DIR/bos-runner.sh" >> "$LOG_FILE" 2>&1 0</dev/null

# Writing to pipe is blocking so, send first command after bos-runner is running in background.
echo "run" > "${ACTION_FILE_PATH}"

exit 0
